<?php
/**
 * Moon core functions.
 *
 * @since   1.0.0
 * @package Moon
 */

if ( ! function_exists( 'nq_moon_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function nq_moon_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Moon, use a find and replace
		 * to change 'moon' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'moon', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'moon' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/*
		 * Enable support for Post Formats.
		 * See https://developer.wordpress.org/themes/functionality/post-formats/
		 */
		add_theme_support( 'post-formats', array(
			'gallery',
			'video',
			'quote',
			'audio',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'nq_moon_custom_background_args', array(
			'default-color' => 'f2f2f2',
			'default-image' => '',
		) ) );

		// Support custom-header
		add_theme_support( 'custom-header' );

		// Tell TinyMCE editor to use a custom stylesheet.
		add_editor_style();
	}
	endif; // nq_moon_setup
add_action( 'after_setup_theme', 'nq_moon_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function nq_moon_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nq_moon_content_width', 820 );
}
add_action( 'after_setup_theme', 'nq_moon_content_width', 0 );

/**
 * Flush out the transients used in nq_moon_categorized_blog.
 *
 * @since  1.0.0
 */
function nq_moon_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'moon_categories' );
}
add_action( 'edit_category', 'nq_moon_category_transient_flusher' );
add_action( 'save_post',     'nq_moon_category_transient_flusher' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function nq_moon_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Primary Sidebar', 'moon' ),
			'id'            => 'primary-sidebar',
			'description'   => esc_html__( 'The primary sidebar', 'moon' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	for ( $i = 1, $n = 4; $i <= $n; $i++ ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer Area #', 'moon' ) . $i,
				'id'            => 'footer-' . $i,
				'description'   => sprintf( __( 'The #%s column in footer area', 'moon' ), $i ),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
			)
		);
	}
}
add_action( 'widgets_init', 'nq_moon_widgets_init' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function nq_moon_body_classes( $classes ) {
	// Adds a class of page layout.
	if ( is_page() ) {
		if ( is_page_template( 'right-sidebar.php' ) ) {
			$classes[] = 'right-sidebar';
		} elseif ( is_page_template( 'no-sidebar.php' ) ) {
			$classes[] = 'no-sidebar';
		}
	} elseif ( is_home() ) {
		$layout = get_theme_mod( 'blog_layout' );
		if ( $layout == 'right-sidebar' ) {
			$classes[] = 'right-sidebar';
		} elseif ( $layout == 'no-sidebar' ) {
			$classes[] = 'no-sidebar';
		}
	}
	
	return $classes;
}
add_filter( 'body_class', 'nq_moon_body_classes' );

/**
 * Enqueue scripts and styles.
 * @since 1.0.0
 */
function nq_moon_enqueue_scripts() {
	// Google font
	if ( 'off' !== _x( 'on', 'Google font: on or off', 'moon' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Raleway:300,400,600,700' ), "//fonts.googleapis.com/css" );
    }
    wp_enqueue_style( 'moon-raleway-fonts', $font_url );

    // Icon Font
	wp_enqueue_style( 'moon-fonts', get_template_directory_uri() . '/assets/css/fonts.css' );

	// Owl Carousel
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.css' );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array(), '', true );

	// Main stylesheet
	wp_enqueue_style( 'moon-style', get_stylesheet_uri(), array( 'dashicons' ) );

	// Inline stylesheet
	wp_add_inline_style( 'moon-style', nq_moon_custom_css() );

	// Nivo lightbox.
	wp_enqueue_script( 'nivo-lightbox', get_template_directory_uri() . '/assets/js/nivo-lightbox.min.js', array(), '', true );

	// Load Moon scripts.
	wp_enqueue_script( 'moon-functions', get_template_directory_uri() . '/assets/js/functions.js', array( 'jquery' ), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	do_action( 'nq_moon_scripts');
}
add_action( 'wp_enqueue_scripts', 'nq_moon_enqueue_scripts' );